* analysis_all_vars.do - merge analysis sample with estimated fixed effects, compute new vars, and produce descriptives
* David Card, Ana Rute Cardoso, Patrick Kline
* "Bargaining, Sorting, and the Gender Wage Gap: Quantifying the Impact of Firms on the Relative Pay of Women" 
* QJE 22684

set more 1
program drop _all
capture log close
log using ..\logs\analysis_all_vars.log, replace


* read estimates AKM models 

program define readakm
   import delimited idworker idfirm year pe_`1' fe_`1' xb_`1' r_`1' v1 v2 v3 v4 using ..\data\AKMeffs_`1'.txt, clear
   recast double idworker idfirm 
   recode idfirm 88888888 = 653075

   label variable pe_`1' "person effect, `1'"

   keep idworker idfirm year pe_`1' fe_`1' xb_`1' r_`1'
   save ..\data\AKMeffs_`1'.dta, replace

   collapse fe_`1', by(idfirm)
   label variable fe_`1' "firm effect, `1'"
   save ..\data\firmeffs_`1'.dta, replace
end

readakm  m
readakm  f
readakm  mpink
readakm  mblue
readakm  fpink
readakm  fblue


* merge worker effects 

use ..\data\AKMeffs_mpink.dta, clear
merge 1:1 idworker year using ..\data\AKMeffs_mblue.dta, update
assert _merge!=3
drop _merge
merge 1:1 idworker year using ..\data\AKMeffs_fpink.dta, update
assert _merge!=3
drop _merge
merge 1:1 idworker year using ..\data\AKMeffs_fblue.dta, update
assert _merge!=3
drop _merge
merge 1:1 idworker year using ..\data\AKMeffs_m.dta, update
drop _merge
merge 1:1 idworker year using ..\data\AKMeffs_f.dta, update
drop _merge


* connected sets worker belongs to

foreach p in "" pink blue {
   gen byte tmpsetworker`p'=1 if pe_m`p'!=. | pe_f`p'!=.
   egen tmp2setworker`p'=total(tmpsetworker`p'), by(idworker)
   gen byte setworker`p'=(tmp2setworker`p'>=1)
   label variable setworker`p' "worker in connected set `p' (YN)"
}

keep idworker idfirm year pe_* fe_* xb_* r_* setworker*
save ..\data\AKMeffs_all.dta, replace


* merge firm effects

use ..\data\firmeffs_mpink.dta, clear
merge 1:1 idfirm using ..\data\firmeffs_mblue.dta, update
drop _merge
merge 1:1 idfirm using ..\data\firmeffs_fpink.dta, update
drop _merge
merge 1:1 idfirm using ..\data\firmeffs_fblue.dta, update
drop _merge
merge 1:1 idfirm using ..\data\firmeffs_m.dta, update
drop _merge
merge 1:1 idfirm using ..\data\firmeffs_f.dta, update
drop _merge


* connected sets firm belongs to

label define setfirmlb 1 "males only" 2 "females only" 3 "both gender"

foreach p in "" pink blue {
   gen setfirm`p'=3 if fe_m`p'!=. & fe_f`p'!=.
   replace setfirm`p'=1 if fe_m`p'!=. & fe_f`p'==.
   replace setfirm`p'=2 if fe_m`p'==. & fe_f`p'!=.
   label values setfirm`p' setfirmlb
   label variable setfirm`p' "firm in connected set `p' (m,f,both)"
}

keep idfirm fe_* setfirm*
compress    fe_* setfirm*
save ..\data\firmeffs_all.dta, replace


* firms: merge QP_BvD & fixed effects

use ..\data\firms_analysis_02_09.dta, clear
merge m:1 idfirm using ..\data\firmeffs_all.dta
keep if _merge==3 | _merge==1
drop _merge

keep year idfirm lisbon oporto ind sizeanalysis avempl sharefemales lVApe lsalesQPpe nkeyvars fe_m* fe_f* setfirm* 
save ..\data\tmpfirms.dta, replace


* workers: merge QP and fixed effects

use  ..\data\workers_analysis_02_09.dta, clear
merge m:1 idfirm year using ..\data\tmpfirms.dta, update
keep if _merge==3
drop _merge
merge 1:1 year idworker idfirm using ..\data\AKMeffs_all.dta, update
keep if _merge==3 | _merge==1
drop _merge


* average lVApe and lsalesQPpe, outliers trimmed

egen avlVApe=mean(lVApe), by(idfirm)
replace avlVApe=. if avlVApe<=1.7 | avlVApe>=4.5
egen avlsalesQPpe=mean(lsalesQPpe), by(idfirm)

keep year idworker idfirm gender age educ occup3 occup1 pink wbase wmin lwage Dlwage lwpeers hnorm hextra hireddate ft lisbon oporto ind size* avempl sharefemales lVApe lsalesQPpe avlVApe avlsalesQPpe nkeyvars pe_* fe_* xb_* r_* setworker* setfirm* 
sum
save ..\data\workers_all_info.dta, replace


* av. VA and Sales into firm file

keep idfirm avlVApe avlsalesQPpe
bys idfirm: keep if _n==1
merge 1:m idfirm using ..\data\tmpfirms.dta
keep if _merge==3

keep year idfirm lisbon oporto ind sizeanalysis avempl sharefemales lVApe lsalesQPpe avlVApe avlsalesQPpe nkeyvars fe_m* fe_f* setfirm* 
sum
save ..\data\firms_all_info.dta, replace


*** table 1: descriptives

program define descworkers
    use ..\data\workers_all_info.dta if `1', clear

    gen dage30less=(age<=30)
    gen dage50more=(age>=50)

    gen deduc12=(educ==12)
    gen deduc16=(educ==16)

    sum idworker age dage* educ deduc12 deduc16 lwage hnorm lisbon oporto sizeQP sharefemales avlVApe
    codebook idworker idfirm
end


* analysis sample
descworkers "gender==0"
descworkers "gender==1"

* connected set
descworkers "gender==0 & setworker==1"
descworkers "gender==1 & setworker==1"

* double connected set
descworkers "gender==0 & setworker==1 & setfirm==3"
descworkers "gender==1 & setworker==1 & setfirm==3"

* analysis sample with VA
descworkers "gender==0 & avlVApe!=."
descworkers "gender==1 & avlVApe!=."


*** data for figure B1

use year gender lwage using ..\data\workers_analysis_02_09.dta, clear
collapse lwage, by(year gender)
save ..\data\for_figure_B1.dta, replace


*** table B3

use idfirm lwage educ using ..\data\workers_all_info.dta, clear
collapse lwage educ, by(idfirm)

merge 1:m idfirm using ..\data\firms_all_info.dta
keep if setfirm==3

gen hotels=(ind==2700)
gen textiles=(ind==1500)
gen trade=(ind==2600)

gen lowVA=1 if avlVApe<2.45 
replace lowVA=0 if avlVApe>=2.45 & avlVApe!=.

collapse lwage educ sizeanalysis sharefem avlsalesQPpe hotels textiles trade lowVA, by(idfirm) 

bys lowVA: sum sizeanalysis, detail
bys lowVA: sum educ sharefem lwage avlsalesQPpe hotels textiles trade


*** table A2

use ..\data\workers_all_info.dta, clear

gen matched=(nkeyvars!=.)

tab ind, missing
tab ind, sum(matched)
tab ind, sum(gender)
bys gender: tab ind, sum(matched)


*** single sex firms

use idworker idfirm year gender lwage sharefemales ind sizeanalysis using ..\data\workers_all_info.dta, clear

tab gender, missing
tab gender if sharefemales==0, sum(lwage) missing
tab gender if sharefemales==1, sum(lwage) missing
count if (sharefemales==0 | sharefemales==1) & sizeanalysis==1

tab ind gender if sharefemales==0, missing column nofreq
tab ind gender if sharefemales==1, missing column nofreq


*** export for event study and `grid search'

use idworker idfirm year lwage gender age educ setfirm fe_m fe_f avlVApe using ..\data\workers_all_info.dta, clear
keep if setfirm==3

ren idworker id
ren idfirm firmid
ren lwage y
ren gender female 
bys female: sum
save ..\data\tmp_toexport.dta, replace

program define forevent
   use ..\data\tmp_toexport.dta if female==`1', clear
   keep id firmid year y age educ female
   sum
   save ../data/for_event_study_`2'.dta, replace
end
forevent 0 males
forevent 1 females


program define forgridsearch
   use ..\data\tmp_toexport.dta if female==`1', clear
   keep if avlVApe!=.
   ren avlVApe ava
   keep id firmid year y female age educ female fe_m fe_f ava
   sum
   save ..\data\for_gridsearch_`2'.dta, replace
end
forgridsearch 0 males
forgridsearch 1 females

log close
