*****************************************************************
* This script computes the bootstraps used in the symmetry test * 
* described in footnote 22 of the paper.  						*
* The followup script compute_symmetry_test.do takes the        *
* bootstrap results and computes test statistics.		        *
*****************************************************************
use eventspells.dta

*Make regressors manually
*note: Stata leaves out "main effect" of continuous variables

xi i.yr i.educ i.educ|age i.educ|agesq

reg dws _I* age agesq if female==1
predict yhatf if female==1
reg dws _I* age agesq if female==0
predict yhatm if female==0
gen gap=dw-yhatf if female==1
replace gap=dw-yhatm if female==0

compare gap dwr if samefirm==0


*make cross id for two-way clustering
egen crossid=group(lagfirmid firmid)

*Cleanup before loop
keep dw age agesq lagfirmid firmid crossid _I* female qlom lagqlom samefirm


*********************************
*Start by clustering on lagfirmid
*********************************

postfile lag0 x12 x13 x14 x23 x24 x34 using bs_lag0, replace
postfile lag1 x12 x13 x14 x23 x24 x34 using bs_lag1, replace
gen w=.
forvalues b=1/1000{
	
bsample , cluster(lagfirmid) weight(w)

forvalues f=0/1{
*get resids
qui reg dw _I* age agesq if samefirm==1&female==`f' [fw=w]
predict yhat if samefirm==0&female==`f'
gen gap=dw-yhat
drop yhat

*now average the resids

local counter=1
forvalues q=1/3{
	forvalues m=`q'/4{

qui{
sum gap [fw=w] if qlom==`q'&lagqlom==`m'&female==`f'&samefirm==0
local sum`q'`m'=r(mean)

sum gap [fw=w] if qlom==`m'&lagqlom==`q'&female==`f'&samefirm==0
local sum`q'`m'=`sum`q'`m''+r(mean)
}
}
}
drop gap
/*
di "Here's what I've got:"
di "12: `sum12'" 
di "13: `sum13'"
di "14: `sum14'" 
di "23: `sum23'"
di "24: `sum24'"
di "34: `sum34'"
*/
post lag`f' (`sum12') (`sum13') (`sum14') (`sum23') (`sum24') (`sum34')
}

}
postclose lag0
postclose lag1

**********************
*Now cluster on firmid
**********************

postfile lead0 x12 x13 x14 x23 x24 x34 using bs_lead0, replace
postfile lead1 x12 x13 x14 x23 x24 x34 using bs_lead1, replace
forvalues b=1/1000{
	
bsample , cluster(firmid) weight(w)

forvalues f=0/1{
*get resids
qui reg dw _I* age agesq if samefirm==1&female==`f' [fw=w]
predict yhat if samefirm==0&female==`f'
gen gap=dw-yhat
drop yhat

*now average the resids

local counter=1
forvalues q=1/3{
	forvalues m=`q'/4{

qui{
sum gap [fw=w] if qlom==`q'&lagqlom==`m'&female==`f'&samefirm==0
local sum`q'`m'=r(mean)

sum gap [fw=w] if qlom==`m'&lagqlom==`q'&female==`f'&samefirm==0
local sum`q'`m'=`sum`q'`m''+r(mean)
}
}
}
drop gap
/*
di "Here's what I've got:"
di "12: `sum12'" 
di "13: `sum13'"
di "14: `sum14'" 
di "23: `sum23'"
di "24: `sum24'"
di "34: `sum34'"
*/
post lead`f' (`sum12') (`sum13') (`sum14') (`sum23') (`sum24') (`sum34')
}

}
postclose lead0
postclose lead1


*****************************
*Now cluster on both firmids
*****************************

postfile both0 x12 x13 x14 x23 x24 x34 using bs_both0, replace
postfile both1 x12 x13 x14 x23 x24 x34 using bs_both1, replace
gen w=.
forvalues b=1/1000{
	
bsample , cluster(crossid) weight(w)

forvalues f=0/1{
*get resids
qui reg dw _I* age agesq if samefirm==1&female==`f' [fw=w]
predict yhat if samefirm==0&female==`f'
gen gap=dw-yhat
drop yhat

*now average the resids

local counter=1
forvalues q=1/3{
	forvalues m=`q'/4{

qui{
sum gap [fw=w] if qlom==`q'&lagqlom==`m'&female==`f'&samefirm==0
local sum`q'`m'=r(mean)

sum gap [fw=w] if qlom==`m'&lagqlom==`q'&female==`f'&samefirm==0
local sum`q'`m'=`sum`q'`m''+r(mean)
}
}
}
drop gap
/*
di "Here's what I've got:"
di "12: `sum12'" 
di "13: `sum13'"
di "14: `sum14'" 
di "23: `sum23'"
di "24: `sum24'"
di "34: `sum34'"
*/
post both`f' (`sum12') (`sum13') (`sum14') (`sum23') (`sum24') (`sum34')
}

}
postclose both0
postclose both1







