%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% This script computes the bootstrap standard error   %
% of our bivariate NLLS estimate of the kinkpoint tau %
% Note: this requires the script Q_SUR.m              %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

today=date %date
rng(187) %set seed
data=dlmread('firmlevel.txt');

va=data(:,2);
fe_m=data(:,3);
fe_f=data(:,4);
n=data(:,5);

N=size(va,1);

k0=2.5;
options=optimset('Display','Iter','TolFun',1e-12,'TolX',1e-8)
khat=fminsearch(@(x)Q_SUR(x,fe_m,fe_f,va,n,0),k0,options)
bhat=Q_SUR(khat,fe_m,fe_f,va,n,1)

%bootstrap
tic
B=1000;
bs_k=NaN(B,1);
bs_b=NaN(B,4);
W=mnrnd(N,1/N*ones(1,N),B)'; %generate BS weights
verify=all(sum(W,1)==N) %each draw of weights should sum to one
options=optimset('Display','off','TolFun',1e-10,'TolX',1e-6)
parfor i=1:B    
w=W(:,i);
bs_k(i,1)=fminsearch(@(x)Q_SUR(x,fe_m,fe_f,va,w.*n,0),khat,options);
b=Q_SUR(khat,fe_m,fe_f,va,w.*n,1);
bs_b(i,:)=b';
end
toc

mean_k=mean(bs_k)
sd_k=std(bs_k)

mean_b=mean(bs_b)
sd_b=std(bs_b)

bs_params=[bs_k,bs_b];
disp('Saving BS reps to disk..')
dlmwrite('bsdata.csv',bs_params);
