* firm_models.do - estimate firm models: relationship between gender-specific firm effects and measures of firm surplus
* David Card, Ana Rute Cardoso, Patrick Kline
* "Bargaining, Sorting, and the Gender Wage Gap: Quantifying the Impact of Firms on the Relative Pay of Women" 
* QJE 22684

set more 1
program drop _all
capture log close
log using ..\logs\firm_models.log, replace


* firms in double connected set

use ..\data\workers_all_info.dta, clear
keep if setfirm==3


* normalize firm fixed effects

foreach g in m f {
	qui sum fe_`g' if avlVApe<2.45 
	gen fe_`g'nva = fe_`g' - r(mean) 

	qui sum fe_`g' if avlsalesQPpe<3.35 
	gen fe_`g'nsal = fe_`g' - r(mean)
}


* excess surplus: av VA in excess of 2.45 or av sales in excess of 3.35

gen excVA=max(0,avlVApe-2.45) if avlVApe!=.
gen excSales=max(0,avlsalesQPpe-3.35) if avlsalesQPpe!=.
label variable excVA    "VApe in excess of 2.45"
label variable excSales "SalesQPpe in excess of 3.35"


* industry dummy vars.

xi, prefix(i) i.ind


* firm av. yearly employment

gen avempth=avempl/1000
gen avempth2=avempth^2


* firm total py 2002-2009

egen npy = count(idworker), by(idfirm)
label variable npy "total # workers in firm, 2002-09"


sort idfirm year
by idfirm: keep if _n==_N
keep idfirm  fe_m fe_f fe_mnva fe_fnva fe_mnsal fe_fnsal excVA excSales avlsalesQPpe nkeyvar lisbon oporto iind* avempth* npy
save ..\data\movers_regression.dta, replace



* regressions movers

* table 5

regress        fe_fnva excVA [aweight=npy], cluster(idfirm)
ivregress 2sls fe_fnva (fe_mnva=excVA) [aweight=npy], first cluster(idfirm)

regress        fe_f avlsalesQPpe [aweight=npy], cluster(idfirm)
ivregress 2sls fe_f (fe_m=avlsalesQPpe) [aweight=npy], first cluster(idfirm)

regress        fe_fnsal excSales [aweight=npy], cluster(idfirm)
ivregress 2sls fe_fnsal (fe_mnsal=excSales) [aweight=npy], first cluster(idfirm)


* table A3 (first row same as table 5)

regress        fe_fnva excVA [aweight=npy] if nkeyvar>=3, cluster(idfirm)
ivregress 2sls fe_fnva (fe_mnva=excVA) [aweight=npy] if nkeyvar>=3, first cluster(idfirm)

regress        fe_fnva excVA [aweight=npy] if nkeyvar>=4, cluster(idfirm)
ivregress 2sls fe_fnva (fe_mnva=excVA) [aweight=npy] if nkeyvar>=4, first cluster(idfirm)

regress        fe_fnva excVA [aweight=npy] if nkeyvar==5, cluster(idfirm)
ivregress 2sls fe_fnva (fe_mnva=excVA) [aweight=npy] if nkeyvar==5, first cluster(idfirm)


* table B8

regress        fe_fnva excVA avempth avempth2 lisbon oporto iind* [aweight=npy], cluster(idfirm)
ivregress 2sls fe_fnva (fe_mnva=excVA) avempth avempth2 lisbon oporto iind* [aweight=npy], first cluster(idfirm)

regress        fe_f avlsalesQPpe avempth avempth2 lisbon oporto iind* [aweight=npy], cluster(idfirm)
ivregress 2sls fe_f (fe_m=avlsalesQPpe) avempth avempth2 lisbon oporto iind* [aweight=npy], first cluster(idfirm)

regress        fe_fnsal excSales avempth avempth2 lisbon oporto iind* [aweight=npy], cluster(idfirm)
ivregress 2sls fe_fnsal (fe_mnsal=excSales) avempth avempth2 lisbon oporto iind* [aweight=npy], first cluster(idfirm)


log close